==> cscec5b-op-impl-3.0.0-20220921.085300-6-sources.jar: com/ejianc/business/op/vo/ApplyDetailVO.java <==
package com.ejianc.business.op.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 申请子实体
 *
 * @author generator
 *
 */
public class ApplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long applyId; // 主表主键
    private String code; // 编码
    private String name; // 名称
    private String spec; // 型号
    private String unit; // 单位
    private BigDecimal num; // 数量
    private String reason; // 出场原因
    private String memo; // 备注
    private Long opMaterialId; // 出门物资主键


    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getOpMaterialId() {
        return opMaterialId;
    }

    public void setOpMaterialId(Long opMaterialId) {
        this.opMaterialId = opMaterialId;
    }

}

==> cscec5b-op-impl-3.0.0-20220923.064238-14-sources.jar: com/ejianc/business/op/vo/ApplyDetailVO.java <==
package com.ejianc.business.op.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 申请子实体
 *
 * @author generator
 *
 */
public class ApplyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long applyId; // 主表主键
    private String code; // 编码
    private String name; // 名称
    private String spec; // 型号
    private String unit; // 单位
    private BigDecimal num; // 数量
    private String reason; // 出场原因
    private String memo; // 备注
    private Long opMaterialId; // 出门物资主键
    private Long opMaterialSpecId; // 出门物资规格主键
    private Long opMaterialUnitId; // 出门物资单位主键


    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    @ReferSerialTransfer(referCode="cscec5b-op-material")
    public Long getOpMaterialId() {
        return opMaterialId;
    }

    @ReferDeserialTransfer
    public void setOpMaterialId(Long opMaterialId) {
        this.opMaterialId = opMaterialId;
    }

    @ReferSerialTransfer(referCode="cscec5b-op-material-spec")
    public Long getOpMaterialSpecId() {
        return opMaterialSpecId;
    }

    @ReferDeserialTransfer
    public void setOpMaterialSpecId(Long opMaterialSpecId) {
        this.opMaterialSpecId = opMaterialSpecId;
    }

    @ReferSerialTransfer(referCode="cscec5b-op-material-unit")
    public Long getOpMaterialUnitId() {
        return opMaterialUnitId;
    }

    @ReferDeserialTransfer
    public void setOpMaterialUnitId(Long opMaterialUnitId) {
        this.opMaterialUnitId = opMaterialUnitId;
    }
}
